/** 
 * Message sent to client
 */

export class ClientMessage {
    /** 
     * Message type
     */
    messageType!: MessageType;
}

/** 
 * Authenticated message
*/
export class ClientAuthenticatedMessage extends ClientMessage
{
    /** 
     * Authentication data
     */
    threeDS!: ThreeDS;
}


/** 
 * Rejected message
*/
export class ClientRejectedMessage extends ClientMessage
{
    /** 
     * Reject Reason
     */
    reason!: string;
}

/** 
 * FingerPrint Required message
*/
export class ClientFingerPrintRequiredMessage extends ClientMessage
{
    /** 
     * Uri of the Device fingerprint flow src
     */
    fingerPrintUri!: string;

    /** 
     * Additional data used for Device fingerprint flow
     */
    fingerPrintData!: string;
}

/** 
 * Challenge Required message
*/
export class ClientChallengeRequiredMessage extends ClientMessage
{
    /** 
     * Url to use for the client  challenge flow
     */
    ascUri!: string;
}

/**
 * Technical problem message
*/
export class ClientTechnicalProblemDetectedMessage extends ClientMessage
{

    /** 
     * Reason for technical problem
     */
    reason!: string;

    /**
     * MPI Reference
     */
    reference!: string;
}


/**
 * Model of received 3DS data
 */
export class ThreeDS
{
    /** 
     * Authentication Value
    */
    authenticationValue!: string;
    /** 
     * ECI
    */
    eci!: string;

    /** 
     * Transaction Id
    */
    xid!: string;

    /** 
     * 3DS version
    */
    version!: string;

    /** 
     * (masterCard) Service level Indication
    */
    sli!: string;
}

/** 
 * Client message type enumeration
*/
export type MessageType =

    /** 
     * The initial state
     */
    "NeverUsed" |

    /** 
     * Authenticated
     */
    "Authenticated" |

    /** 
     * Rejected
     */
    "Rejected"|

    /** 
     * Device FingerPrint Required
     */
    "FingerPrintRequired"|

    /** 
     * Device FingerPrint Required
     */
    "FingerPrintCompleted"|

    /** 
     * Challenge required
     */
    "ChallengeRequired"|

    /** 
     * A technical problem
     */
    "TechnicalProblem"|

    /** 
     * Card is not enrolled for 3DS
     */
    "CardNotEnrolled"|

    /** 
     * No response has been received from MPI
     */
    "NoResponse";
